/*
 * Copyright (c) 2008
 * Embedded Brains GmbH
 * Obere Lagerstr. 30
 * D-82178 Puchheim
 * Germany
 * rtems@embedded-brains.de
 *
 * The license and distribution terms for this file may be found in the file
 * LICENSE in this distribution or at http://www.rtems.com/license/LICENSE.
 */

package org.rtems.cdt.build;

import org.eclipse.cdt.managedbuilder.core.IManagedCommandLineGenerator;
import org.eclipse.cdt.managedbuilder.core.IManagedCommandLineInfo;
import org.eclipse.cdt.managedbuilder.core.ITool;
import org.eclipse.cdt.managedbuilder.internal.core.ManagedCommandLineGenerator;
import org.eclipse.core.resources.IProject;
import org.rtems.cdt.Constants;
import org.rtems.cdt.Storage;

public class CommandLineGenerator extends ManagedCommandLineGenerator implements IManagedCommandLineGenerator {
	public IManagedCommandLineInfo generateCommandLineInfo(
		ITool tool,
		String commandName,
		String [] flags,
		String outputFlag,
		String outputPrefix,
		String outputName,
		String [] inputResources,
		String commandLinePattern
	) {
		// Get associated project of the tool
		IProject project = (IProject) tool.getParentResourceInfo().getParent().getOwner();
		
		// Determine main command name via the tool ID
	    String id = tool.getId();
	    String name = "-gcc";    
	    if (id.contains( "archiver")) {
	    	name = "-ar";
	    } else if (id.contains( "assembler")) {
	    	name = "-as";
	    } else if (id.contains( "cpp.compiler")) {
	    	name = "-g++";
	    } else if (id.contains( "cpp.linker")) {
	    	name = "-g++";
	    }
		
	    // Create and set command name
		commandName = new String(
			Storage.getProperty( project, Constants.TARGET_KEY)
				+ "-rtems"
				+ Storage.getProperty( project, Constants.VERSION_KEY)
				+ name
		);
		tool.setToolCommand( commandName);

		return super.generateCommandLineInfo(
			tool,
			commandName,
			flags,
			outputFlag,
			outputPrefix,
			outputName,
			inputResources,
			commandLinePattern
		);
	}
}
